package com.lib_utils;

import java.util.List;

import android.app.ActivityManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.Build;

public class AppInfoUtils {

    public static String getCurProcessName(Context context) {

        int pid = android.os.Process.myPid();

        ActivityManager activityManager = (ActivityManager) context
                .getSystemService(Context.ACTIVITY_SERVICE);

        // 判断得到的 ActivityManager 是否为空
        if (activityManager != null) {
            for (ActivityManager.RunningAppProcessInfo appProcess : activityManager
                    .getRunningAppProcesses()) {

                if (appProcess.pid == pid) {
                    return appProcess.processName;
                }
            }
        }

        return null;
    }

    /**
     * 获取应用的版本号
     * @param context
     * @return
     */
    public static int getAppVersionCode(Context context) {

        int versioncode = -1;
        try {
            if (null != context) {
                PackageManager pm = context.getPackageManager();
                PackageInfo pi = pm.getPackageInfo(context.getPackageName(), 0);
                versioncode = pi.versionCode;
            }
        } catch (Exception e) {
        }
        return versioncode;
    }

    /**
     * 获取应用的版本名称
     *
     * @param context
     * @return String versionName
     */
    public static String getVersionName(Context context) {
        String versionName = null;
        try {
            String packageName = context.getApplicationContext().getPackageName();
            versionName = context.getPackageManager().getPackageInfo(packageName, 0).versionName;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return versionName;
    }

    /**
     * 获取应用信息
     *
     * @param context
     * @return PackageInfo info
     */
    public static PackageInfo getAppPackageInfo(Context context) {
        PackageManager manager = null;
        PackageInfo info = null;
        manager = context.getPackageManager();
        try {
            info = manager.getPackageInfo(context.getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return info;
    }

    /**
     * 方法一：
     * 判断当前应用程序处于前台还是后台
     * <uses-permission android:name="android.permission.GET_TASKS" />
     */
    public static boolean isApplicationBroughtToBackground(final Context context) {
        ActivityManager am = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        List<ActivityManager.RunningTaskInfo> tasks = am.getRunningTasks(1);
        if (!tasks.isEmpty()) {
            ComponentName topActivity = tasks.get(0).topActivity;
            if (!topActivity.getPackageName().equals(context.getPackageName())) {
                return true;
            }
        }
        return false;
    }

    //判断无效
    public static boolean isBackground(Context context) {
        ActivityManager activityManager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        List<ActivityManager.RunningAppProcessInfo> appProcesses = activityManager.getRunningAppProcesses();
        for (ActivityManager.RunningAppProcessInfo appProcess : appProcesses) {
            if (appProcess.processName.equals(context.getPackageName())) {
                if (appProcess.importance == ActivityManager.RunningAppProcessInfo.IMPORTANCE_BACKGROUND) {
                    return true; //后台
                } else {
                    return false; //前台
                }
            }
        }
        return false;
    }

    /**
     * 检测当前packageName程序是否属于前台程序
     *
     * @param appPackageName
     * @return
     */
    public static boolean isTopActivity(Context context, String appPackageName) {

        ActivityManager activityManager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        List<ActivityManager.RunningTaskInfo> tasksInfo = activityManager.getRunningTasks(1);
        if (tasksInfo.size() > 0) {
            String top = tasksInfo.get(0).topActivity.getPackageName();
            if (top.contains(appPackageName)) {
                return true;
            }
        }
        return false;
    }

    /**
     * 获取当前Activity的名字
     *
     * @param context
     * @return
     */
    public static String getTopActivityName(Context context) {
        String packname = ""; /* Android5.0之后获取程序锁的方式是不一样的*/
        ActivityManager activityManager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
        if (Build.VERSION.SDK_INT > 20) {
            // 5.0及其以后的版本
            List<ActivityManager.RunningAppProcessInfo> tasks = activityManager.getRunningAppProcesses();
            if (null != tasks && tasks.size() > 0) {
                packname = tasks.get(0).processName;
            }
        } else {
            // 5.0之前
            // 获取正在运行的任务栈(一个应用程序占用一个任务栈) 最近使用的任务栈会在最前面
            // 1表示给集合设置的最大容量 List<RunningTaskInfo> infos = am.getRunningTasks(1);
            // 获取最近运行的任务栈中的栈顶Activity(即用户当前操作的activity)的包名
            packname = activityManager.getRunningTasks(1).get(0).topActivity.getPackageName();
        }

        return packname;
    }
}
