package com.lib_utils;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.text.DecimalFormat;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.util.Base64;
import android.util.Log;

/**
 * 单位转换工具类
 * @author Alfred_Huang
 * 
 */
public class ConvertUtils {

	
	public int macStringToInt(String macString) {
		String macTemp;
		macTemp = getLow4BytesOfMac(macString);
		byte[] macBytes = hexStringToBytes(macTemp);
		return byteToInt(macBytes);
	}

	public String getLow4BytesOfMac(String macString) {
		macString = macString.substring(6);
		macString = macString.replace("-", "");
		return macString;
	}

	/**
	 * Convert byte[] to hex
	 * 
	 * @param src byte[] data
	 * 
	 * @return hex string
	 */
	public static String bytesToHexString(byte[] src) {
		StringBuilder stringBuilder = new StringBuilder("");
		if (src == null || src.length <= 0) {
			return null;
		}
		for (int i = 0; i < src.length; i++) {
			int v = src[i] & 0xFF;
			String hv = Integer.toHexString(v);
			if (hv.length() < 2) {
				stringBuilder.append(0);
			}
			stringBuilder.append(hv);
		}
		return stringBuilder.toString();
	}

	public static String oneByteToHexString(byte oneByte) {
		StringBuilder stringBuilder = new StringBuilder("");
		int v = oneByte & 0xFF;
		String hv = Integer.toHexString(v);
		if (hv.length() < 2) {
			stringBuilder.append(0);
		}
		stringBuilder.append(hv);
		return stringBuilder.toString();
	}

	/**
	 * Convert hex string to byte[]
	 * 
	 * @param hexString
	 *            the hex string
	 * @return byte[]
	 */
	public static byte[] hexStringToBytes(String hexString) {
		if (hexString == null || hexString.equals("")) {
			return null;
		}
		hexString = hexString.toUpperCase();
		int length = hexString.length() / 2;
		char[] hexChars = hexString.toCharArray();
		byte[] d = new byte[length];
		for (int i = 0; i < length; i++) {
			int pos = i * 2;
			d[i] = (byte) (charToByte(hexChars[pos]) << 4 | charToByte(hexChars[pos + 1]));
		}
		return d;
	}

	/**
	 * Convert char to byte
	 * 
	 * @param c
	 *            char
	 * @return byte
	 */
	private static byte charToByte(char c) {
		return (byte) "0123456789ABCDEF".indexOf(c);
	}

	/**
	 * 转换short为byte
	 * 
	 * @param s
	 * @return
	 */
	public static byte[] shortToByte(short number) {
		int temp = number;
		byte[] b = new byte[2];
		for (int i = 0; i < b.length; i++) {
			b[i] = new Integer(temp & 0xff).byteValue();
			temp = temp >> 8;
		}
		return b;
	}

	/**
	 * 转换byte为short
	 * 
	 * @param b
	 * @return
	 */
	public static short byteToShort(byte[] b) {
		if (b == null)
			return 0;

		short s = 0;
		short s0 = (short) (b[0] & 0xff);
		short s1 = (short) (b[1] & 0xff);
		s1 <<= 8;
		s = (short) (s0 | s1);
		return s;
	}

	/** 转换long为byte **/
	public static byte[] longToByte(long number) {
		long temp = number;
		byte[] b = new byte[8];
		for (int i = 0; i < b.length; i++) {
			b[i] = new Long(temp & 0xff).byteValue();
			temp = temp >> 8;
		}
		return b;
	}

	/** 转换byte为long **/
	public static long byteToLong(byte[] b) {
		long s = 0;
		long s0 = b[0] & 0xff;
		long s1 = b[1] & 0xff;
		long s2 = b[2] & 0xff;
		long s3 = b[3] & 0xff;
		long s4 = b[4] & 0xff;
		long s5 = b[5] & 0xff;
		long s6 = b[6] & 0xff;
		long s7 = b[7] & 0xff;

		// s0����
		s1 <<= 8;
		s2 <<= 16;
		s3 <<= 24;
		s4 <<= 8 * 4;
		s5 <<= 8 * 5;
		s6 <<= 8 * 6;
		s7 <<= 8 * 7;
		s = s0 | s1 | s2 | s3 | s4 | s5 | s6 | s7;
		return s;
	}

	/**
	 * 转换int为byte
	 * 
	 * @param number
	 * @return
	 */
	public static byte[] intToByte(int number) {
		int temp = number;
		byte[] b = new byte[4];
		for (int i = 0; i < b.length; i++) {
			b[i] = new Integer(temp & 0xff).byteValue();
			temp = temp >> 8;
		}
		return b;
	}

	/**
	 * 转换byte为int
	 * 
	 * @param b
	 * @return
	 */
	public static int byteToInt(byte[] b) {
		int s = 0;
		int s0 = b[0] & 0xff;// ���λ
		int s1 = b[1] & 0xff;
		int s2 = b[2] & 0xff;
		int s3 = b[3] & 0xff;
		s3 <<= 24;
		s2 <<= 16;
		s1 <<= 8;
		s = s0 | s1 | s2 | s3;
		return s;
	}

	/** 转换字符串为数字 */
	public static int strToInt(String value, int defaultValue) {
		try {
			return Integer.valueOf(value);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 转换字符串为数字 */
	public static long strToInt(String value, long defaultValue) {
		try {
			return Long.valueOf(value);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 转换16进制字符串为数字 */
	public static int hexToInt(String value, int defaultValue) {
		try {
			return Integer.parseInt(value, 16);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 转换16进制字符串为数字 */
	public static long hexToInt(String value, long defaultValue) {
		try {
			return Long.parseLong(value, 16);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 转换字符串为数字 */
	public static float strToFloat(String value, float defaultValue) {
		try {
			return Float.valueOf(value);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 转换字符串为数字 */
	public static double strToDouble(String value, double defaultValue) {
		try {
			return Double.valueOf(value);
		} catch (Exception e) {
			return defaultValue;
		}
	}

	/** 通过四舍五入的方式转换float为int **/
	public static int floatToInt(float value) {
		if (value > 0) {
			return (int) (value + 0.5);
		} else if (value < 0) {
			return (int) (value - 0.5);
		} else {
			return 0;
		}
	}

	/**
	 * base64转为bitmap
	 * 
	 * @param base64Data
	 * @return
	 */
	public static Bitmap base64ToBitmap(String base64Data) {
		try {

			byte[] bytes = Base64.decode(base64Data, Base64.DEFAULT);
			return BitmapFactory.decodeByteArray(bytes, 0, bytes.length);
		} catch (IllegalArgumentException ex) {
			ex.printStackTrace();
			return null;
		}

	}

	/**
	 * bitmap转为base64
	 * 
	 * @param bitmap
	 * @return
	 */
	public static String bitmapToBase64(Bitmap bitmap) {

		String result = null;
		ByteArrayOutputStream baos = null;
		try {
			if (bitmap != null) {
				baos = new ByteArrayOutputStream();
				bitmap.compress(Bitmap.CompressFormat.PNG, 100, baos);

				baos.flush();
				baos.close();

				byte[] bitmapBytes = baos.toByteArray();
				result = Base64.encodeToString(bitmapBytes, Base64.DEFAULT);
			}
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (baos != null) {
					baos.flush();
					baos.close();
				}
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return result;
	}

	/**
	 * drawable转为bitmap
	 * 
	 * @param drawable
	 * @return
	 */
	public static Bitmap drawableToBitamp(Drawable drawable) {

		BitmapDrawable bd = (BitmapDrawable) drawable;
		return bd.getBitmap();
	}

	
	/**
	 * String转为BASE64编码后的String
	 * 
	 * @param string
	 * @return String base64String
	 */
	public static String base64Encode(String string) {
		try {
			return string == null ? null : Base64.encodeToString(string.getBytes(), Base64.DEFAULT);
		} catch (Exception ex) {
			ex.printStackTrace();
			return null;
		}

	}
	
	/**
	 * byte[]转为BASE64编码后的String
	 * 
	 * @param base64Data
	 * @return String encodeToString
	 */
	public static String base64EncodeBuffer(byte[] base64Data) {
		try {
			return base64Data == null ? null : Base64.encodeToString(base64Data, Base64.DEFAULT);
		} catch (Exception ex) {
			ex.printStackTrace();
			return null;
		}

	}
	
	/**
	 * BASE64 编码自定义flag
	 * 
	 * @param s
	 * @return
	 */
	public static String base64EncodeBuffer(byte[] base64Data, int flag) {
		try{
			return base64Data == null?null:Base64.encodeToString(base64Data, flag);
		}catch(Exception ex)
		{
			ex.printStackTrace();
			return null;
		}

	}

	/**
	 * BASE64编码后的String转为byte[]
	 * 
	 * @param base64String
	 * @return byte[] decodeTobyte[]
	 */
	public static byte[] base64DecodeBufferToByte(String base64String) {
		if (base64String == null) {
			return null;
		}
		byte[] result;
		try {
			return result = Base64.decode(base64String, Base64.DEFAULT);
		} catch (Exception ex) {
			ex.printStackTrace();
			return null;
		}
	}

	/**
	 * BASE64编码后的String转为String
	 * 
	 * @param base64String
	 * @return byte[] decodeTobyte[]
	 */
	public static String base64DecodeBuffer(String base64String) {
		if (base64String == null) {
			return null;
		}
		byte[] result;
		try {
			result = Base64.decode(base64String, Base64.DEFAULT);
			return new String(result);
		} catch (Exception ex) {
			ex.printStackTrace();
			return null;
		}
	}
	
	/**
	 * 
	 * @param byteForConvert
	 * @param convertFormat "#0.0" 表示保留一位小数 "#0.00"表示保留两位小数
	 * @return String convResult
	 * @exception Log ("字节单位数值或格式有误");
	 */
	public static String setByteUnitConvert(long byteForConvert, String convertFormat) {
		float convNum = 0;
		String unit = "B";
		float convByte = byteForConvert;
		DecimalFormat df = new DecimalFormat(convertFormat);
		// 字节单位换算
		if (convByte >= 1024 * 1024) {
			// 1MB
			convNum = convByte / 1024 / 1024;
			unit = "MB";
		} else if (convByte >= 1024) {
			// 1KB
			convNum = convByte / 1024;
			unit = "KB";
		} else if (convByte >= 0) {
			// 1B
			convNum = convByte;
			unit = "B";
		} else {
			AlsLog.printLog("字节单位数值或格式有误");
		}
		return df.format(convNum) + unit;
	}
	
}
