package com.lib_utils;

import android.app.Activity;
import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Environment;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;

import org.apache.http.util.EncodingUtils;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Comparator;

/**
 * 文件工具类
 *
 * @author Alfred_Huang
 */
public class FileUtils {

	/**
	 * inner class 通过修改时间 进行从旧到新排序类
	 *
	 * @author Alfred_Huang
	 */
	public static class FileComparator implements Comparator<File> {
		public int compare(File file1, File file2) {
			if (file1.lastModified() < file2.lastModified()) {
				return -1;
			} else {
				return 1;
			}
		}
	}

	/**
	 * 根据后缀名获得文件类型
	 *
	 * @param f
	 * @return [audio] [video] [image]
	 */
	public static String getMIMEType(File f) {
		String type = "";
		String fName = f.getName();
		String end = fName.substring(fName.lastIndexOf(".") + 1, fName.length()).toLowerCase();

		if (end.equals("m4a") || end.equals("mp3") || end.equals("mid") || end.equals("xmf") || end.equals("ogg")
				|| end.equals("wav") || end.equals("flac")) {
			type = "audio";
		} else if (end.equals("3gp") || end.equals("mp4")) {
			type = "video";
		} else if (end.equals("jpg") || end.equals("gif") || end.equals("png") || end.equals("jpeg")
				|| end.equals("bmp")) {
			type = "image";
		} else {
			type = "*";
		}
		return type;
	}

	/**
	 * 通过文件名称获取资源文件文本内容
	 *
	 * @param fileName
	 *            [e.g. "test.txt"]
	 * @param context
	 * @return
	 */
	public static String readFileFromAssets(String fileName, Context context) {
		// String fileName = "test.txt"; //文件名字
		String content = "";
		try {

			// 得到资源中的asset数据流
			InputStream in = context.getResources().getAssets().open(fileName);

			int length = in.available();
			byte[] buffer = new byte[length];

			in.read(buffer);
			in.close();
			content = EncodingUtils.getString(buffer, "UTF-8");

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
		return content;
	}

	/**
	 * 通过文件名称获取sdcard文件文本内容
	 *
	 * @param fileName
	 * @return
	 * @throws IOException
	 */
	public static String readFileFromSdcard(String fileName) throws IOException {
		String content = "";
		try {
			FileInputStream fin = new FileInputStream(fileName);
			int length = fin.available();
			byte[] buffer = new byte[length];
			fin.read(buffer);
			content = EncodingUtils.getString(buffer, "UTF-8");
			fin.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return content;
	}

	public static File getFileByUri(Activity mActivity, Uri receivedUri) {
		File file = null;
		if (receivedUri != null) {
			Log.e("TAG", receivedUri.toString());
			if (receivedUri.getScheme() != null && receivedUri.getScheme().toString().equals("content")) {
				String[] proj = { MediaStore.Images.Media.DATA };
				Cursor musicCursor = ((Activity) mActivity).managedQuery(receivedUri, proj, null, null, null);
				if (musicCursor != null) {
					int actual_music_column_index = musicCursor.getColumnIndexOrThrow(MediaStore.Images.Media.DATA);
					musicCursor.moveToFirst();
					String musicPath = musicCursor.getString(actual_music_column_index);
					if (musicPath != null) {
						file = new File(musicPath);
					}
				}
			} else if (receivedUri.getScheme() != null && receivedUri.getScheme().compareTo("file") == 0) {
				// file:///开头的uri
				try {
					file = new File(new URI(receivedUri.toString()));
				} catch (URISyntaxException e) {
					e.printStackTrace();
				}
			} else {
				// file:///开头的uri
				try {
					file = new File(receivedUri.toString());
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}
		return file;
	}

	public static File getFileByName(String appFolder, String subFolder, String fileName) {
		// /* 将项目名称加版本号作为apk文件名*/
		// File apkFile = new
		// File(Environment.getExternalStorageDirectory().getAbsolutePath(),
		// AppConfig.APP_PATH + AppConfig.currentUpdate.getDownUrl());
		/* 直接将项目名称作为apk文件名 */
		File file = new File(appFolder + File.separator + subFolder + File.separator
				+ (TextUtils.isEmpty(fileName) ? "" : fileName));
		// File directory = file.getParentFile();// 目录
		// if (!directory.exists() && !directory.mkdirs()) {
		// return file;
		// }
		// 如果目录存在, mkdirs创建此抽象路径名指定的目录, 包括所有必需但不存在的父目录; mkdir只能在存在的目录中创建文件
		if (!TextUtils.isEmpty(fileName)) {
			File directory = file.getParentFile();// 目录
			if (!directory.exists() && !directory.mkdirs()) {
				return file;
			}
		} else {
			if (!file.exists() && !file.mkdirs()) {
				return file;
			}
		}
		return file;
	}

	public static boolean deleteFileByName(String appFolder, String subFolder, String fileName) {
		File file = new File(
				appFolder + File.separator + subFolder + File.separator + (fileName == null ? "" : fileName));
		// return file.exists() ? file.delete() : false;
		return delete(file);
	}

	private static boolean delete(File file) {
		if (file.isFile()) {
			return file.delete();
		}
		if (file.isDirectory()) {
			File[] childFiles = file.listFiles();
			if (childFiles == null || childFiles.length == 0) {
				return file.delete();
			}
			for (int i = 0; i < childFiles.length; i++) {
				delete(childFiles[i]);
			}
			return file.delete();
		}
		return file.exists();
	}

	/**
	 * 判断SD卡是否可用
	 */
	public static boolean isSdCardExist() {
		return Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED);
	}

	/**
	 * 获取SD卡跟路径。SD卡不可用时，返回null
	 */
	public static String getSDcardRoot() {
		if (isSdCardExist()) {
			return Environment.getExternalStorageDirectory().getAbsolutePath();
		}

		return null;
	}

	/**
	 * 获取字符串中某个字符串出现的次数。
	 */
	public static int countMatches(String res, String findString) {
		if (res == null) {
			return 0;
		}

		if (findString == null || findString.length() == 0) {
			throw new IllegalArgumentException("The param findString cannot be null or 0 length.");
		}

		return (res.length() - res.replace(findString, "").length()) / findString.length();
	}

	/**
	 * 判断该文件是否是一个图片。
	 */
	public static boolean isImage(String fileName) {
		return fileName.endsWith(".jpg") || fileName.endsWith(".jpeg") || fileName.endsWith(".png");
	}

	/**
	 * 保存方法
	 */
	public void saveBitmap(Bitmap bmp, String picName) {
		File f = new File("/sdcard/ImgProcess/", picName);
		if (f.exists()) {
			f.delete();
		}
		try {
			FileOutputStream out = new FileOutputStream(f);
			bmp.compress(Bitmap.CompressFormat.PNG, 100, out);
			out.flush();
			out.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
