package com.lib_utils;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * 时间相关工具类
 * @author Alfred_Huang
 *
 */
public class TimeUtils {
	
	/**
	 * 获取当前系统时间：参数类型为时间格式
	 * 
	 * @param timeFormat "yyyy-MM-dd HH:mm:ss" or "HH:mm" and others.
	 * @return String sdf.format(dateTime)
	 */
	public static String getCurrentTime(String timeFormat){
		return formatTimeToString(System.currentTimeMillis(), timeFormat);
	}
	
	/**
	 * 格式化时间
	 * 
	 * @param timeMillis
	 * @param param timeFormat "yyyy-MM-dd HH:mm:ss" or "HH:mm" and others.
	 * @return
	 */
	public static String formatTimeToString(long timeMillis, String timeFormat) {
		SimpleDateFormat sdf = new SimpleDateFormat(timeFormat);
		Date dateTime = new Date(timeMillis);
		return sdf.format(dateTime);
	}
	
	/**
	 * 
	 * @param str1
	 * @param str2
	 * @param format "HHmm" etc.
	 * @return
	 */
	public static long[] getDistanceTimes(String str1, String str2, String format) {
		DateFormat df = new SimpleDateFormat(format);
		Date date1;
		Date date2;
		long day = 0;
		long hour = 0;
		long min = 0;
		long sec = 0;
		try {
			date1 = df.parse(str1);
			date2 = df.parse(str2);
			long time1 = date1.getTime();
			long time2 = date2.getTime();
			long diff;
			if (time1 < time2) {
				diff = time2 - time1;
			} else {
				diff = time1 - time2;
//				diff = time2 + 24 * 60 * 60 * 1000 - time1;
			}
			day = diff / (24 * 60 * 60 * 1000);
			hour = (diff / (60 * 60 * 1000) - day * 24);
			min = ((diff / (60 * 1000)) - day * 24 * 60 - hour * 60);
			sec = (diff / 1000 - day * 24 * 60 * 60 - hour * 60 * 60 - min * 60);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		long[] times = { day, hour, min, sec };
		return times;
	}
}
