package com.lib_utils.receiver;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.wifi.WifiManager;
import android.os.Parcelable;
import android.util.Log;

import com.lib_utils.NetworkUtils;

/**
 * filter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
 * filter.addAction("android.net.wifi.WIFI_STATE_CHANGED");
 * filter.addAction("android.net.wifi.STATE_CHANGE");
 */
public class NetworkConnectChangedReceiver extends BroadcastReceiver {

    private OnNetworkChangeListener listener;

    @Override
    public void onReceive(Context context, Intent intent) {
        // 这个监听wifi的打开与关闭，与wifi的连接无关  
        if (WifiManager.WIFI_STATE_CHANGED_ACTION.equals(intent.getAction())) {
            int wifiState = intent.getIntExtra(WifiManager.EXTRA_WIFI_STATE, 0);
            switch (wifiState) {
                case WifiManager.WIFI_STATE_DISABLED:
                    //引导用户打开设置
//                    Log.e("onReceive", "WIFI_STATE_DISABLED");
                    break;
                case WifiManager.WIFI_STATE_DISABLING:
//                    Log.e("onReceive", "WIFI_STATE_DISABLING");
                    break;
                case WifiManager.WIFI_STATE_ENABLING:
//                    Log.e("onReceive", "WIFI_STATE_ENABLING");
                    break;
                case WifiManager.WIFI_STATE_ENABLED:
                    //网络可用
//                    Log.e("onReceive", "WIFI_STATE_ENABLED");
                    break;
                case WifiManager.WIFI_STATE_UNKNOWN:
//                    Log.e("onReceive", "WIFI_STATE_UNKNOWN");
                    break;
                default:
                    break;
            }
        }

        // 这个监听wifi的连接状态即是否连上了一个有效无线路由，当上边广播的状态是WifiManager  
        // .WIFI_STATE_DISABLING，和WIFI_STATE_DISABLED的时候，根本不会接到这个广播。  
        // 在上边广播接到广播是WifiManager.WIFI_STATE_ENABLED状态的同时也会接到这个广播，  
        // 当然刚打开wifi肯定还没有连接到有效的无线  
        if (WifiManager.NETWORK_STATE_CHANGED_ACTION.equals(intent.getAction())) {
            Parcelable parcelableExtra = intent.getParcelableExtra(WifiManager.EXTRA_NETWORK_INFO);
            if (null != parcelableExtra) {
                NetworkInfo networkInfo = (NetworkInfo) parcelableExtra;
                NetworkInfo.State state = networkInfo.getState();
                boolean isConnected = state == NetworkInfo.State.CONNECTED;
                if (isConnected) {
                    //网络可用
//                    Log.e("onReceive", "WIFI_网络可用");
                } else {
                    //网络不可用
//                    Log.e("onReceive", "WIFI_网络不可用");
                }
            }
        }

        // 最好用的还是这个监听。Wifi/移动网打开，关闭，以及连接上可用的连接都会接到监听  
        // 这个广播的最大弊端是比上边两个广播的反应要慢，如果只是要监听wifi用上边两个配合比较合适  
        if (ConnectivityManager.CONNECTIVITY_ACTION.equals(intent.getAction())) {
            ConnectivityManager manager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
            NetworkInfo activeNetwork = manager.getActiveNetworkInfo();
            if (activeNetwork != null) { // connected to the internet  
                if (activeNetwork.isConnected()) {
                    if (activeNetwork.getType() == ConnectivityManager.TYPE_WIFI) {
                        // connected to wifi
                        Log.e("onReceive", "connected to wifi");
                        if (listener != null){
                            listener.onChanged(NetworkUtils.NETWORK_WIFI);
                        }
                    } else if (activeNetwork.getType() == ConnectivityManager.TYPE_MOBILE) {
                        // connected to the mobile signal
                        Log.e("onReceive", "connected to the mobile signal");
                        if (listener != null){
                            listener.onChanged(NetworkUtils.NETWORK_MOBILE);
                        }
                    }
                } else {
                    //无网络连接
                    Log.e("onReceive", "No Connection...");
                }
            } else {   // not connected to the internet
                //无网络连接
                Log.e("onReceive", "No Network Connection...");
                if (listener != null){
                    listener.onChanged(NetworkUtils.NETWORK_NONE);
                }
            }
        }
    }

    public void setNetworkChangeListener(OnNetworkChangeListener listener){
        this.listener = listener;
    }

    public interface OnNetworkChangeListener{
        void onChanged(int state);
    }
} 